import { IAsyncEnumerable, IAsyncEqualityComparer, IEqualityComparer, IGrouping, SelectorKeyType } from "../../types";
declare type GroupByAsyncFunc = {
    /**
     * Groups the elements of a sequence according to a specified key selector function.
     * @param source An Iterable<T> whose elements to group.
     * @param keySelector A function to extract the key for each element.
     * @returns An AsyncIterable<IGrouping<TKey, TSource>>
     * where each IGrouping<TKey,TElement> object contains a sequence of objects and a key.
     */
    <TSource, TKey extends SelectorKeyType>(source: AsyncIterable<TSource>, keySelector: (x: TSource) => Promise<TKey> | TKey): IAsyncEnumerable<IGrouping<TKey, TSource>>;
    /**
     * Groups the elements of a sequence according to a specified key selector function.
     * @param source An AsyncIterable<T> whose elements to group.
     * @param keySelector A function to extract the key for each element.
     * @param comparer An IEqualityComparer<T> or IAsyncEqualityComparer<T> to compare keys.
     * @returns An IAsyncEnumerable<IGrouping<TKey, TSource>>
     * where each IGrouping<TKey,TElement> object contains a sequence of objects and a key.
     */
    <TSource, TKey>(source: AsyncIterable<TSource>, keySelector: (x: TSource) => Promise<TKey> | TKey, comparer: IEqualityComparer<TKey> | IAsyncEqualityComparer<TKey>): IAsyncEnumerable<IGrouping<TKey, TSource>>;
};
export declare const groupByAsync: GroupByAsyncFunc;
export {};
