declare type MaxFunc = {
    /**
     * Returns the maximum value in a sequence of values.
     * @param source A sequence of values to determine the maximum value of.
     * @throws {InvalidOperationException} source contains no elements.
     * @returns The maximum value in the sequence.
     */
    (source: AsyncIterable<number>): Promise<number>;
    /**
     * Invokes a transform function on each element of a sequence and returns the maximum value.
     * @param source A sequence of values to determine the maximum value of.
     * @param selector A transform function to apply to each element.
     * @throws {InvalidOperationException} source contains no elements.
     * @returns The maximum value in the sequence.
     */
    <TSource>(source: AsyncIterable<TSource>, selector: (x: TSource) => number): Promise<number>;
};
export declare const max: MaxFunc;
export {};
