"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.averageAsync = void 0;
const shared_1 = require("../../shared");
const _nextIterationAsync_1 = require("./_nextIterationAsync");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Computes the average of a sequence of values
 * that are obtained by invoking a transform function on each element of the input sequence.
 * @param source A sequence of values to calculate the average of.
 * @param selector A transform function to apply to each element.
 * @throws {InvalidOperationException} source contains no elements.
 * @returns Average value (from the selector) of this parallel sequence
 */
const averageAsync = async (source, selector) => {
    const nextIter = (0, _nextIterationAsync_1.nextIterationAsync)(source, selector);
    const values = await (0, _typeDataToArray_1.typeDataToArray)(nextIter);
    if (values.length === 0) {
        throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoElements);
    }
    let value = 0;
    for (const selectedValue of values) {
        value += selectedValue;
    }
    return value / values.length;
};
exports.averageAsync = averageAsync;
