import { IAsyncEqualityComparer, IEqualityComparer, IGrouping, IParallelEnumerable, SelectorKeyType } from "../../types";
declare type GroupByAsyncFunc = {
    /**
     * Groups the elements of a sequence according to a specified key selector function.
     * @param source An IAsyncParallel<T> whose elements to group.
     * @param keySelector A function to extract the key for each element.
     * @returns An IParallelEnumerable<IGrouping<TKey, TSource>>
     * where each IGrouping<TKey,TElement> object contains a sequence of objects and a key.
     */
    <TSource, TKey extends SelectorKeyType>(source: IParallelEnumerable<TSource>, keySelector: (x: TSource) => Promise<TKey> | TKey): IParallelEnumerable<IGrouping<TKey, TSource>>;
    /**
     * Groups the elements of a sequence according to a specified key selector function.
     * @param source An IAsyncParallel<T> whose elements to group.
     * @param keySelector A function to extract the key for each element.
     * @param comparer An IEqualityComparer<T> or IAsyncEqualityComparer<T> to compare keys.
     * @returns An IParallelEnumerable<IGrouping<TKey, TSource>>
     * where each IGrouping<TKey,TElement> object contains a sequence of objects and a key.
     */
    <TSource, TKey>(source: IParallelEnumerable<TSource>, keySelector: (x: TSource) => Promise<TKey> | TKey, comparer: IEqualityComparer<TKey> | IAsyncEqualityComparer<TKey>): IParallelEnumerable<IGrouping<TKey, TSource>>;
};
export declare const groupByAsync: GroupByAsyncFunc;
export {};
