"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ofType = void 0;
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
const _nextIteration_1 = require("./_nextIteration");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Applies a type filter to a source iteration
 * @param source Async Iteration to Filtery by Type
 * @param type Either value for typeof or a consturctor function
 * @returns Values that match the type string or are instance of type
 */
const ofType = (source, type) => {
    const typeCheck = typeof type === "string" ?
        (x) => [typeof x === type, x] :
        (x) => [x instanceof type, x];
    const generator = async () => {
        const dataFunc = (0, _nextIteration_1.nextIteration)(source, typeCheck);
        const values = await (0, _typeDataToArray_1.typeDataToArray)(dataFunc);
        const filteredValues = [];
        for (const [pass, value] of values) {
            if (pass) {
                filteredValues.push(value);
            }
        }
        return filteredValues;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 0 /* PromiseToArray */,
    });
};
exports.ofType = ofType;
