"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.partitionAsync = void 0;
const _nextIterationAsync_1 = require("./_nextIterationAsync");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Paritions the AsyncIterable<T> into a tuple of failing and passing arrays
 * based on the predicate.
 * @param source Elements to Partition
 * @param predicate Pass / Fail condition
 * @returns [pass, fail]
 */
const partitionAsync = async (source, predicate) => {
    const dataFunc = (0, _nextIterationAsync_1.nextIterationAsync)(source, async (value) => {
        const passed = await predicate(value);
        return [passed, value];
    });
    const values = await (0, _typeDataToArray_1.typeDataToArray)(dataFunc);
    const fail = [];
    const pass = [];
    for (const [passed, value] of values) {
        if (passed) {
            pass.push(value);
        }
        else {
            fail.push(value);
        }
    }
    return [pass, fail];
};
exports.partitionAsync = partitionAsync;
