import { IParallelEnumerable } from "../../types";
declare type SelectFunc = {
    /**
     * Projects each element of a sequence into a new form.
     * @param source A sequence of values to invoke a transform function on.
     * @param selector A transform function to apply to each element.
     * @returns
     * An IParallelEnumerable<T> whose elements are the result of invoking the transform function on each element of source.
     */
    <TSource, OUT>(source: IParallelEnumerable<TSource>, selector: (x: TSource) => OUT): IParallelEnumerable<OUT>;
    /**
     * Projects each element of a sequence into a new form.
     * @param source A sequence of values to invoke a transform function on.
     * @param selector A key of TSource.
     * @returns
     * An IParallelEnumerable<T> whose elements are the result of getting the value from the key on each element of source.
     */
    <TSource, TKey extends keyof TSource>(source: IParallelEnumerable<TSource>, key: TKey): IParallelEnumerable<TSource[TKey]>;
};
export declare const select: SelectFunc;
export {};
