import { IAsyncParallel } from "../../types";
declare type SumFunc = {
    /**
     * Computes the sum of a sequence of values.
     * @param source A sequence of values to calculate the sum of.
     * @returns The sum of the values in the sequence.
     */
    (source: IAsyncParallel<number>): Promise<number>;
    /**
     * Computes the sum of the sequence of values
     * that are obtained by invoking a transform function on each element of the input sequence.
     * @param source A sequence of values that are used to calculate a sum.
     * @param selector A transform function to apply to each element.
     * @returns The sum of the projected values.
     */
    <TSource>(source: IAsyncParallel<TSource>, selector: (x: TSource) => number): Promise<number>;
};
export declare const sum: SumFunc;
export {};
