"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sumAsync = void 0;
const _nextIterationAsync_1 = require("./_nextIterationAsync");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Computes the sum of the sequence of numeric values that are obtained by invoking a transform function
 * on each element of the input sequence.
 * @param source A sequence of values that are used to calculate a sum.
 * @param selector A transform function to apply to each element.
 * @returns Sum of the sequence
 */
const sumAsync = async (source, selector) => {
    const dataFunc = (0, _nextIterationAsync_1.nextIterationAsync)(source, selector);
    const values = await (0, _typeDataToArray_1.typeDataToArray)(dataFunc);
    let sum = 0;
    for (const value of values) {
        sum += value;
    }
    return sum;
};
exports.sumAsync = sumAsync;
