"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toMap = void 0;
const _nextIteration_1 = require("./_nextIteration");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Converts an IParallelEnumerable<V> to a Map<K, V[]>.
 * @param source An IParallelEnumerable<V> to convert.
 * @param selector A function to serve as a key selector.
 * @returns A promise for Map<K, V[]>
 */
const toMap = async (source, selector) => {
    const map = new Map();
    const dataFunc = (0, _nextIteration_1.nextIteration)(source, (value) => {
        const key = selector(value);
        return [key, value];
    });
    const keyValues = await (0, _typeDataToArray_1.typeDataToArray)(dataFunc);
    for (const [key, value] of keyValues) {
        const array = map.get(key);
        if (array === undefined) {
            map.set(key, [value]);
        }
        else {
            array.push(value);
        }
    }
    return map;
};
exports.toMap = toMap;
