"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.whereAsync = void 0;
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
const _nextIterationWithIndexAsync_1 = require("./_nextIterationWithIndexAsync");
const _typeDataToArray_1 = require("./_typeDataToArray");
/**
 * Filters a sequence of values based on a predicate.
 * Each element's index is used in the logic of the predicate function.
 * @param source An IAsyncParallel<T> to filter.
 * @param predicate A async function to test each source element for a condition;
 * the second parameter of the function represents the index of the source element.
 * @returns An IParallelEnumerable<T> that contains elements from the input sequence that satisfy the condition.
 */
const whereAsync = (source, predicate) => {
    const generator = async () => {
        const dataFunc = (0, _nextIterationWithIndexAsync_1.nextIterationWithIndexAsync)(source, async (value, index) => {
            const keep = await predicate(value, index);
            return [keep, value];
        });
        const valuesAsync = await (0, _typeDataToArray_1.typeDataToArray)(dataFunc);
        const filteredValues = [];
        for (const [keep, value] of valuesAsync) {
            if (keep) {
                filteredValues.push(value);
            }
        }
        return filteredValues;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 0 /* PromiseToArray */,
    });
};
exports.whereAsync = whereAsync;
