import { IEnumerable } from "../../types";
declare type ZipFunc = {
    /**
     * Creates a tuple of corresponding elements of two sequences, producing a sequence of the results.
     * @param first The first sequence to merge.
     * @param second The second sequence to merge.
     * @returns An IEnumerable<[TFirst, TSecond]> that contains merged elements of two input sequences.
     */
    <TFirst, TSecond>(first: Iterable<TFirst>, second: Iterable<TSecond>): IEnumerable<[TFirst, TSecond]>;
    /**
     * Applies a specified function to the corresponding elements of two sequences, producing a sequence of the results.
     * @param first The first sequence to merge.
     * @param second The second sequence to merge.
     * @param resultSelector A function that specifies how to merge the elements from the two sequences.
     * @returns An IEnumerable<TResult> that contains merged elements of two input sequences.
     */
    <TFirst, TSecond, TResult>(first: Iterable<TFirst>, second: Iterable<TSecond>, resultSelector: (x: TFirst, y: TSecond) => TResult): IEnumerable<TResult>;
};
export declare const zip: ZipFunc;
export {};
